package com.hungraim.ltc.account.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.account.service.AccountService;
import com.hungraim.ltc.pojo.entity.account.*;
import com.hungraim.ltc.pojo.vo.account.*;
import com.hungraim.ltc.util.FileUtils;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * 结算管理控制层
 */
@RestController
@RequestMapping("/api.account/account")
@AllArgsConstructor
@Slf4j
public class AccountController {

    private final AccountService accountService;

    /**
     * 添加或修改结算记录
     *
     * @return 返回状态
     */
    @PostMapping("/addOrUpdateAccount")
    public Result addOrUpdateAccount(AccountOperVo accountOperVo) {
     /*   if (null == accountOperVo.getSrvOrganId() || null == accountOperVo.getAccountsTime() || StringUtils.isBlank(accountOperVo.getTotalExpensesPayable()) || null == accountOperVo.getAccountsStatus()) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }*/
        Long accountsId = accountOperVo.getAccountsId();
        Date accountsTime = accountOperVo.getAccountsTime();
        Long srvOrganId = accountOperVo.getSrvOrganId();
        if (null == accountsId) {
            List<ChDisabAccounts> list = accountService.list(new LambdaQueryWrapper<ChDisabAccounts>().eq(ChDisabAccounts::getAccountsTime, accountsTime).eq(ChDisabAccounts::getSrvOrganId, srvOrganId));
            if (null != list && list.size() > 0) {
                return Result.failed("当前机构当月已存在结算数据");
            }
        }
        accountService.addOrUpdateAccount(accountOperVo);
        return Result.success();
    }

    /**
     * 查询结算信息列表
     *
     * @param srvOrganListReq 请求参数对象
     * @return 返回雷彪
     */
    @GetMapping("/searchSrvOrganList")
    public Result<Page<SrvOrganListResp>> searchSrvOrganList(SrvOrganListReq srvOrganListReq) {
        return Result.success(accountService.searchSrvOrganList(srvOrganListReq));
    }

    /**
     * 获取结算详情
     *
     * @param accountsId 结算id
     * @return 返回机构结算详情
     */
    @GetMapping("/srvOrganDetail")
    public Result<AccountOperVo> getSrvOrganDetail(Long accountsId) {
        if (null == accountsId) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        return Result.success(accountService.getSrvOrganDetail(accountsId));
    }

    /**
     * 费用结算
     *
     * @return  返回机构结当月算详情
     */
    @GetMapping("/expenseSettlement")
    public Result<ExpenseVo> expenseSettlement(ExpenseSettlementReq req) throws ParseException {
        if (null == req.getSrvOrganId() || StringUtils.isBlank(req.getAccountsTime())) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        if (req.getPageNum() == null) {
            req.setPageNum(1);
        }
        if (req.getPageSize() == null) {
            req.setPageSize(10);
        }
        return Result.success(accountService.expenseSettlement(req));
    }



    /**
     * 任务执行
     *
     * @return
     */
    @PostMapping("/organAccountTaskExecute")
    public Result organAccountTaskExecute(AccountTaskReqVO accountTaskReqVO){
        List<AccountTaskExecuteReqVO> accountTaskExecuteReqVOS = accountTaskReqVO.getAccountTaskList();
        Result result = accountService.accountTaskExecute(accountTaskExecuteReqVOS);
        return result;
    }


    @GetMapping("/getOtherPlace")
    public Result otherPlaceHandler(String programId){
        accountService.otherPlaceHandler(programId);
        return Result.success();
    }



    /**
     * 任务列表
     *
     * @param srvTaskReqVO 请求参数对象
     * @return 返回
     */
    @GetMapping("/getSrvTaskList")
    public Result<Page<SrvTaskRespVO>> getSrvTaskList(SrvTaskReqVO srvTaskReqVO) {
        return Result.success(accountService.getSrvTaskList(srvTaskReqVO));
    }


    /**
     * 查询机构结算审核列表
     *
     * @param srvOrganListReq 请求参数对象
     * @return 返回
     */
    @GetMapping("/searchSrvOrganAccountList")
    public Result<Page<SrvOrganAccountListResp>> searchSrvOrganAccountList(SrvOrganListReq srvOrganListReq) {
        List<String> list = Arrays.asList("1");
        srvOrganListReq.setAccountsStatusList(list);
         return Result.success(accountService.searchSrvOrganAccountList(srvOrganListReq));
    }

    /**
     * 查询机构结算复核列表
     *
     * @param srvOrganListReq 请求参数对象
     * @return 返回
     */
    @GetMapping("/searchSrvOrganReviewList")
    public Result<Page<SrvOrganAccountListResp>> searchSrvOrganReviewList(SrvOrganListReq srvOrganListReq) {
        List<String> list = Arrays.asList("2", "3","4");
        srvOrganListReq.setAccountsStatusList(list);
        return Result.success(accountService.searchSrvOrganAccountList(srvOrganListReq));
    }

    /**
     *  机构结算明细导出
     *
     */
    @GetMapping("/srvOrganAccountExport")
    public void srvOrganAccountExport(SrvOrganListReq req,HttpServletResponse response){
        Workbook workbook = accountService.srvOrganAccountExport(req);
        // 命名表格
        String fileName = "srvOrganAccount.xlsx";
        FileUtils.exportResponse(workbook,fileName,response);
    }









    /**
     * 查询机构结算信息列表明细
     *
     * @param srvOrganListReq
     * @return
     */
    @GetMapping("/queryOrganAccountsDetail")
    public Result<Page<ChDisabDetailAccountsResp>>   queryOrganAccountsDetail(Integer pageNum, Integer pageSize, SrvOrganListReq srvOrganListReq) {
        String accountsId = srvOrganListReq.getAccountsId();
        if (StringUtils.isBlank(accountsId)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        Page<ChDisabDetailAccountsResp> chAssessDetailAccounts = accountService.queryOrganAccountsDetail(pageNum,pageSize,srvOrganListReq);
        return Result.success(chAssessDetailAccounts);
    }


    /**
     * 基金申报列表查询
     * @param
     * @return
     */
    @GetMapping("/queryAccountsDeclareList")
    public Result<Page<ChDisabDetailAccountsResp>>   queryAccountsDeclareList(Integer pageNum, Integer pageSize,SrvOrganListReq srvOrganListReq) {
        List<String> accountsStatusList = Arrays.asList("0", "1");
        srvOrganListReq.setAccountsStatusList(accountsStatusList);
        Page<ChDisabDetailAccountsResp> chAssessDetailAccounts = accountService.queryOrganAccountsDetail(pageNum,pageSize,srvOrganListReq);
        return Result.success(chAssessDetailAccounts);
    }

    /**
     * 暂缓列表查询
     * @param
     * @return
     */
    @GetMapping("/queryDelayAccountList")
    public Result<Page<ChDisabDetailAccountsResp>>   queryDelayAccountList(Integer pageNum, Integer pageSize,SrvOrganListReq srvOrganListReq) {
        List<String> list = Arrays.asList("1", "2");
        srvOrganListReq.setAccountsStatusList(list);
        Page<ChDisabDetailAccountsResp> chAssessDetailAccounts = accountService.queryOrganAccountsDetail(pageNum,pageSize,srvOrganListReq);
        return Result.success(chAssessDetailAccounts);
    }

    /**
     * 暂缓
     * @param  status  1 恢复   2 暂缓
     * @return
     */
    @PostMapping("/delayAccountCommit")
    public Result<Page<ChDisabDetailAccountsResp>> delayAccountCommit(Long accountsDetailId, Short status) {
        int result = accountService.delayAccountCommit(accountsDetailId, status);
        if (result > 0) {
            return Result.success();
        } else {
            return Result.failed("该记录不可操作,请联系管理员");
        }
    }


    /**
     * 基金申报提交
     * @param
     * @return
     */
    @PostMapping("/accountsFreeCommit")
    public Result accountsFreeCommit(Long accountsDetailId) {
        int result = accountService.accountsFreeCommit(accountsDetailId);
        if (result > 0) {
            return Result.success();
        } else {
            return Result.failed("该记录已不可申报，请联系管理员");
        }
    }

    /**
     * 查询护理记录
     *
     * @param nursingReqVO
     * @return
     */
    @GetMapping("/queryNursingRecords")
    public Result<Page<NursingRecordsRespVO>>   queryNursingRecords(NursingReqVO nursingReqVO) {
        if (StringUtils.isBlank(nursingReqVO.getModeName())
                ||StringUtils.isBlank(nursingReqVO.getAccountsTime())
        ||StringUtils.isBlank(nursingReqVO.getDisabInfoId())
        ||StringUtils.isBlank(nursingReqVO.getSrvOrganId())) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        Page<NursingRecordsRespVO> nursingRecordsRespVOList = accountService.queryNursingRecords(nursingReqVO);
        return Result.success(nursingRecordsRespVOList);
    }


    @GetMapping("/queryOverallCostRecords")
    public Result<OverallEduceDecreaseCostRespVO>   queryOverallCostRecords(OverallCostReqVO req) {
        String certiCode = req.getCertiCode();
        if (StringUtils.isBlank(certiCode)) {
            return Result.failed("查询条件证件号不能为空");
        }
        OverallEduceDecreaseCostRespVO overallCostRecords = accountService.queryOverallCostRecords(req);
        return Result.success(overallCostRecords);
    }



    /**
     * 费用扣减提交
     *
     * @param req
     * @return
     */
    @PostMapping("/overallCostSubmit")
    public Result  overallCostSubmit(OverallCostSubmitReqVO req) {
        int result = accountService.overallCostSubmit(req);
        if(result > 0){
            return Result.success();
        }else{
            return Result.failed();
        }
    }

    /**
     * 删除护理机构
     *
     * @param accountsDetailId  结算详情id
     */
    @DeleteMapping("/deleteAccountsDetail")
    public Result deleteAccountsDetail(Long accountsDetailId,Long freeRdId) {
        if (null == accountsDetailId) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        int result = accountService.deleteAccountsDetail(accountsDetailId,freeRdId);
        if(result > 0){
            return Result.success();
        }else{
            return Result.failed();
        }
    }

    @GetMapping("/queryOverallCostList")
    public Result<Page<OverallCostListRespVO>>   queryOverallCostList(OverallCostReqVO req) {
        Page<OverallCostListRespVO> overallCostRecords = accountService.queryFreeRdInfo(req);
        return Result.success(overallCostRecords);
    }

    /**
     * 机构结算管理提交复核
     *
     * @param id 结算id
     * @return 返回雷彪
     */
    @PostMapping("/updatechDisabAccounts")
    public Result updateChDisabAccounts(int id) {
        int bl = accountService.updateChDisabAccounts(id);
        if(bl>0){
            return Result.success();
        }else{
            return Result.failed();
        }

    }


}


