package com.hungraim.ltc.util;


import cn.hutool.core.util.StrUtil;

import java.text.ParseException;
import java.text.ParsePosition;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.TimeZone;

public class DateUtils {

    /**
     * yyyyMMdd 20121225
     */
    public static final String DATE_PATTERN_yyyyMMdd = "yyyyMMdd";

    /**
     * yyyyMMddHHmmss 20121225202020
     */
    public static final String DATE_PATTERN_yyyyMMddHHMMss = "yyyyMMddHHmmss";

    /**
     * yyyyMMddHHmmssSSS
     */
    public static final String DATE_PATTERN_yyyyMMddHHMMssSSS = "yyyyMMddHHmmssSSS";

    /**
     * yyyy-MM-dd 2012-12-25
     */
    public static final String DATE_PATTERN_yyyy_MM_dd = "yyyy-MM-dd";

    public static final String DATE_PATTERN_yyyy_MM = "yyyy-MM";

    /**
     * MM-dd 12月25日
     */
    public static final String DATE_PATTERN_MM_dd = "MM月dd日";

    /**
     * HH:mm:ss 20:20:20
     */
    public static final String DATE_PATTERN_HH_MM_ss = "HH:mm:ss";

    /**
     * HHmmss 202020
     */
    public static final String DATE_PATTERN_HHMMss = "HHmmss";

    /**
     * HH:mm 20:20
     */
    public static final String DATE_PATTERN_HH_MM = "HH:mm";

    /**
     * yyyy-MM-dd HH:mm:ss 2012-12-25 20:20:20
     */
    public static final String DATE_PATTERN_yyyy_MM_dd_HH_MM_ss = "yyyy-MM-dd HH:mm:ss";

    /**
     * 一天的开始时间点 00:00:00
     */
    public static final String START_OF_DAY = " 00:00:00";

    /**
     * 一天的结束时间点 23:59:59
     */
    public static final String END_OF_DAY = " 23:59:59";

    /**
     * :
     */
    public static final String COLON = ":";

    /**
     * 00
     */
    public static final String DEFAULT_SECONDS = "00";

    /**
     * 计算第二天的开始
     *
     * @throws ParseException
     */
    public static Date startOfNextDay(Date aDay) throws ParseException {
        return getDate(anotherDay(aDay, 1));
    }

    /**
     * 获取相对于date前后的某一天
     *
     * @param i 正数获得其后某一天，负数获得之前某一天
     * @throws ParseException
     */
    public static Date anotherDay(Date date, int i) throws ParseException {
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        cal.add(Calendar.DATE, i);
        Date result = cal.getTime();
        return result;
    }

    public static Date intToDate(int i) throws ParseException {
        Date date = new Date(i);

        return date;

    }

    /**
     * 获取相对于date前后的某一天
     *
     * @param i 正数获得其后某一天，负数获得之前某一天
     * @throws ParseException
     */
    public static String anotherDateToStr(String sdate, int i) throws ParseException {
        Date date = strToDate(sdate);
        Date newDate = anotherDay(date, i);
        String newDateS = dateToStr(newDate);
        return newDateS;
    }

    public static Date getDate(Date date) throws ParseException {
        SimpleDateFormat sdf = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd);
        return new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd).parse(sdf.format(date));
    }

    /**
     * 构造格式为HH:mm:ss的Date时间，例如20:20:20
     */
    public static Date constructTimeByStrHhmmss(String timeStr) {
        try {
            return new SimpleDateFormat(DateUtils.DATE_PATTERN_HH_MM_ss).parse(timeStr);
        } catch (ParseException e) {
            throw new RuntimeException(e.getMessage(), e);
        }
    }

    /**
     * 将短时间格式字符串转换为时间 yyyy-MM-dd
     *
     * @param strDate
     * @return
     */
    public static Date strToDate(String strDate) {
        Date strtodate = null;
        if (StrUtil.isNotBlank(strDate)) {
            SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd);
            ParsePosition pos = new ParsePosition(0);
            strtodate = formatter.parse(strDate, pos);
        }

        return strtodate;
    }

    /**
     * 将短时间格式字符串转换为时间 yyyyMMdd
     *
     * @param strDate
     * @return
     */
    public static Date strToDateyyyyMMdd(String strDate) {
        Date strtodate = null;
        if (StrUtil.isNotBlank(strDate)) {
            SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyyMMdd);
            ParsePosition pos = new ParsePosition(0);
            strtodate = formatter.parse(strDate, pos);
        }

        return strtodate;
    }

    /**
     * 将短时间格式字符串转换为时间 yyyy-MM-dd HH:mm:ss
     *
     * @param strDate
     * @return
     */
    public static Date strToTime(String strDate) {
        try {
            SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd_HH_MM_ss);
            ParsePosition pos = new ParsePosition(0);
            Date strtodate = formatter.parse(strDate, pos);
            return strtodate;
        } catch (Throwable e) {
            return null;
        }
    }
    /**
     * 将短时间格式字符串转换为时间 yyyy-MM-dd HH:mm:ss
     *
     * @param strDate
     * @return
     */
    public static Date strToDateMd(String strDate) {
        try {
            SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd);
            ParsePosition pos = new ParsePosition(0);
            Date strtodate = formatter.parse(strDate, pos);
            return strtodate;
        } catch (Throwable e) {
            return null;
        }
    }
    /**
     * 字符串时间戳转日期
     *
     * @param strTime
     * @return
     */
    public static Date strTimeToDate(String strTime) {
        Date strtodate = null;
        if (StrUtil.isNotBlank(strTime)) {
            try {
                SimpleDateFormat format = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd_HH_MM_ss);
                Long time = Long.valueOf(strTime) * 1000;
                String d = format.format(time);
                strtodate = format.parse(d);
            } catch (ParseException e) {
                // TODO Auto-generated catch block
                e.printStackTrace();
            }
        }
        return strtodate;
    }

    /**
     * 将短时间格式时间转换为字符串 yyyy-MM-dd
     *
     * @param dateDate
     * @param
     * @return
     */
    public static String dateToStr(Date dateDate) {
        if (dateDate == null) {
            return "";
        }
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd);
        String dateString = formatter.format(dateDate);
        return dateString;
    }

    /**
     * 将短时间格式时间转换为字符串 yyyy-MM
     *
     * @param dateDate
     * @param
     * @return
     */
    public static String dateToStrYm(Date dateDate) {
        if (dateDate == null) {
            return "";
        }
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyy_MM);
        String dateString = formatter.format(dateDate);
        return dateString;
    }

    /**
     * 将短时间格式时间转换为字符串 yyyyMMdd
     *
     * @param dateDate
     * @param
     * @return
     */
    public static String dateToStryyyyMMdd(Date dateDate) {
        if (dateDate == null) {
            return "";
        }
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyyMMdd);
        String dateString = formatter.format(dateDate);
        return dateString;
    }

    /**
     * Date 类型转为 xxxx年xx月xx日 xx时xx分
     */
    public static String dateToChStr(Date dateDate) {
        if (dateDate == null) {
            dateDate = new Date();
        }
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd);
        String dateCh = formatter.format(dateDate);
        dateCh = dateCh.replaceFirst("-", "年").replaceFirst("-", "月") + "日";
        String hhmmCh = dateToHhMmStr(dateDate);
        hhmmCh = hhmmCh.replace(":", "时") + "分";
        return dateCh + "  " + hhmmCh;
    }

    /**
     * Date 类型转为 xxxx年xx月xx日
     */
    public static String dateToChDateStr(Date dateDate) {
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd);
        String dateCh = formatter.format(dateDate);
        return dateCh.replaceFirst("-", "年").replaceFirst("-", "月") + "日";
    }

    /**
     * 把date转换成yyyy-MM-dd格式的字符串
     * @param date 日期对象
     * @return yyyy-MM-dd字符串
     */
    public static String dateToStr_yyyy_MM_dd(Date date) {
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd);
        String dateCh = formatter.format(date);
        return dateCh;
    }

    /**
     * 将短时间格式时间转换为字符串 yyyy-MM-dd_HH_MM_ss
     *
     * @param dateDate
     * @param
     * @return
     */
    public static String dateTimeToStr(Date dateDate) {
        if (dateDate == null) {
            return "";
        }
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd_HH_MM_ss);
        String dateString = formatter.format(dateDate);
        return dateString;
    }

    /**
     * 将短时间格式时间转换为字符串 yyyy-MM-dd
     *
     * @param dateDate
     * @param
     * @return
     */
    public static String dateToHhMmStr(Date dateDate) {
        if (dateDate == null) {
            return "";
        }
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd);
        String dateString = formatter.format(dateDate);
        return dateString;
    }

    /**
     * 将短时间格式时间转换为字符串 yyyyMMdd
     *
     * @param dateDate
     * @param
     * @return
     */
    public static String dateToStr_YYYYMMDD(Date dateDate) {
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyyMMdd);
        String dateString = formatter.format(dateDate);
        return dateString;
    }

    /**
     * 将时间转换为字符串HHmmss
     *
     * @param dateDate
     * @return
     */
    public static String dateToStr_HHMMSS(Date dateDate) {
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_HHMMss);
        String dateString = formatter.format(dateDate);
        return dateString;
    }


    /**
     * 将时间转换为字符串yyyyMMddHHmmss
     *
     * @param dateDate
     * @return
     */
    public static String dateToStr_yyyyMMddHHMMss(Date dateDate) {
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyyMMddHHMMss);
        String dateString = formatter.format(dateDate);
        return dateString;
    }

    /**
     * 将时间转换为字符串yyyyMMddHHmmssSSS
     *
     * @param dateDate
     * @return
     */
    public static String dateToStr_yyyyMMddHHMMssSSS(Date dateDate) {
        SimpleDateFormat formatter = new SimpleDateFormat(DATE_PATTERN_yyyyMMddHHMMssSSS);
        String dateString = formatter.format(dateDate);
        return dateString;
    }

    /**
     * 根据一个日期，返回是星期几的字符串
     *
     * @param sdate
     * @return
     */
    public static int getWeek(String sdate) {
        // 再转换为时间
        Date date = strToDate(sdate);
        Calendar c = Calendar.getInstance();
        c.setTime(date);
        // 1=星期1 ......... 7=星期日，其他类推
        int week = c.get(Calendar.DAY_OF_WEEK) - 1;
        return week = week == 0 ? 7 : week;
    }

    public static String getWeekStr(String sdate) {
        Date date = strToDate(sdate);
        Calendar c = Calendar.getInstance();
        c.setTime(date);
        return new SimpleDateFormat("EEEE").format(c.getTime());
    }

    /**
     * 获取指定周的开始时间
     *
     * @param now
     * @param timeZoneExpress
     * @return
     */
    public static long getWeekBeginTime(long now, String timeZoneExpress) {
        TimeZone timeZone = TimeZone.getTimeZone(timeZoneExpress);
        Calendar instance = Calendar.getInstance(timeZone);
        instance.setTimeInMillis(now);
        int week = instance.get(Calendar.DAY_OF_WEEK);
        if (week == Calendar.SUNDAY) {
            //取上周周一
            instance.set(Calendar.HOUR_OF_DAY, 0);
            instance.set(Calendar.MINUTE, 0);
            instance.set(Calendar.SECOND, 0);
            instance.set(Calendar.MILLISECOND, 0);
            instance.add(Calendar.DATE, -1);
            instance.set(Calendar.DAY_OF_WEEK, instance.getFirstDayOfWeek());
        } else {
            //
            //取本周周一
            instance.set(Calendar.HOUR_OF_DAY, 0);
            instance.set(Calendar.MINUTE, 0);
            instance.set(Calendar.SECOND, 0);
            instance.set(Calendar.MILLISECOND, 0);
            instance.set(Calendar.DAY_OF_WEEK, instance.getFirstDayOfWeek());
        }
        return instance.getTimeInMillis();
    }

    /**
     * 获取指定周的结束时间
     *
     * @param now
     * @param timeZoneExpress
     * @return
     */
    public static long getWeekEndTime(long now, String timeZoneExpress) {
        TimeZone timeZone = TimeZone.getTimeZone(timeZoneExpress);
        Calendar instance = Calendar.getInstance(timeZone);
        instance.setTimeInMillis(getWeekBeginTime(now, timeZoneExpress));
        instance.add(Calendar.DAY_OF_WEEK, 7);
        return instance.getTimeInMillis();
    }

    /**
     * 计算两个时间间隔
     *
     * @param date1
     * @param date2
     * @return
     */
    public static long getDays(String date1, String date2) {
        if (date1 == null || date1.equals("")) {
            return 0;
        }
        if (date2 == null || date2.equals("")) {
            return 0;
        }
        // 转换为标准时间
        SimpleDateFormat myFormatter = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd);
        Date date = null;
        Date mydate = null;
        try {
            date = myFormatter.parse(date1);
            mydate = myFormatter.parse(date2);
        } catch (Exception e) {
        }
        long day = (date.getTime() - mydate.getTime()) / (24 * 60 * 60 * 1000);
        return day;
    }

    /**
     * 添加月份
     *
     * @param startDate
     * @param addnos
     * @return
     */
    public static Date addMonth(Date startDate, int addnos) {
        Calendar cc = Calendar.getInstance();
        if (startDate != null) {
            cc.setTime(startDate);
            cc.add(Calendar.MONTH, addnos);
            return cc.getTime();
        } else {
            return null;
        }
    }

    /**
     * 添加年份
     *
     * @param date
     * @param addnos
     * @return
     */
    public static Date addYear(Date date, int addnos) {
        Calendar cc = Calendar.getInstance();
        if (date != null) {
            cc.setTime(date);
            cc.add(Calendar.YEAR, addnos);
            return cc.getTime();
        } else {
            return null;
        }
    }

    /**
     * 得到当前年份
     *
     * @return
     */
    public static int getNowYear() {
        Calendar cc = Calendar.getInstance();
        return cc.get(Calendar.YEAR);
    }

    /**
     * 比较两个日期的相差天数,如果开始日期比结束日期早，则返回正数，否则返回负数。
     *
     * @param start
     * @param end
     * @return
     */
    public static long compareDay(Date start, Date end) {
        long day = compareDate(start, end);
        return day / 1000 / 60 / 60 / 24;
    }

    /**
     * 比较两个日期的相差毫秒数,如果开始日期比结束日期早，则返回正数，否则返回负数。
     *
     * @param start 开始日期
     * @param end   结束日期
     * @return
     */
    public static long compareDate(Date start, Date end) {
        long temp = 0;
        Calendar starts = Calendar.getInstance();
        Calendar ends = Calendar.getInstance();
        starts.setTime(start);
        ends.setTime(end);
        temp = ends.getTime().getTime() - starts.getTime().getTime();
        return temp;
    }

    /**
     * 检查当前时间是否实在时间区间内
     *
     * @param start
     * @param end
     * @return
     */
    public static boolean isValidate(String start, String end) {
        Calendar starts = Calendar.getInstance();
        long nowTime = Calendar.getInstance().getTime().getTime();
        Calendar ends = Calendar.getInstance();

        if (StrUtil.isNotBlank(start) && start.length() == 10)
            starts.setTime(strToTime(start + " 00:00:00")); // yyyy-MM-dd HH:mm:ss
        else
            starts.setTime(strToTime("2000-01-01" + " 00:00:00"));

        if (StrUtil.isNotBlank(end) && end.length() == 10)
            ends.setTime(strToTime(end + " 23:59:59")); // yyyy-MM-dd HH:mm:ss
        else
            ends.setTime(strToTime("9999-12-31" + " 23:59:59")); // yyyy-MM-dd HH:mm:ss

        if (starts.getTime().getTime() <= nowTime && nowTime <= ends.getTime().getTime())
            return true;
        return false;
    }

    /**
     * 检查当前时间是否实在时间区间内
     *
     * @param start
     * @param end
     * @return
     */
    public static boolean isValidate(Date start, Date end) {
        Calendar starts = Calendar.getInstance();
        long nowTime = Calendar.getInstance().getTime().getTime();
        Calendar ends = Calendar.getInstance();
        starts.setTime(start);
        ends.setTime(end);
        if (starts.getTime().getTime() <= nowTime && nowTime <= ends.getTime().getTime())
            return true;
        return false;
    }

    /**
     * 给一个日期加上N天或减去N天得到一个新的日期
     *
     * @param startDate 需要增加的日期时间
     * @param addnos    添加的天数，可以是正数也可以是负数
     * @return 操作后的日期
     */
    public static Date AddDay(Date startDate, int addnos) {
        if (startDate == null) {
            startDate = new Date();
        }

        Calendar cc = Calendar.getInstance();
        cc.setTime(startDate);
        cc.add(Calendar.DATE, addnos);
        return cc.getTime();
    }

    /**
     * 获取日期的年
     *
     * @param date
     * @return
     */
    public static Integer getDateYear(Date date) {
        return getYearMonthOrDay(date, "YEAR");
    }

    /**
     * 获取日期月份
     *
     * @param date
     * @return
     */
    public static Integer getDateMonth(Date date) {
        return getYearMonthOrDay(date, "MONTH");
    }

    /**
     * 获取日期天
     *
     * @param date
     * @return
     */
    public static Integer getDateDay(Date date) {
        return getYearMonthOrDay(date, "DAY");
    }

    private static Integer getYearMonthOrDay(Date date, String type) {
        if (null != date && !StrUtil.isEmpty(type)) {
            Calendar c = Calendar.getInstance();
            c.setTime(date);
            if ("YEAR".equals(type)) {
                return new Integer(c.get(Calendar.YEAR));
            } else if ("MONTH".equals(type)) {
                return new Integer(c.get(Calendar.MONTH) + 1);
            } else if ("DAY".equals(type)) {
                return new Integer(c.get(Calendar.DAY_OF_MONTH));
            } else {
                return null;
            }
        } else {
            return null;
        }
    }

    /**
     * 功能描述：返回小时
     *
     * @param date 日期
     * @return 返回小时
     */
    public static int getHour(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        return calendar.get(Calendar.HOUR_OF_DAY);
    }

    /**
     * 功能描述：返回分
     *
     * @param date 日期
     * @return 返回分钟
     */
    public static int getMinute(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        return calendar.get(Calendar.MINUTE);
    }

    /**
     * 返回秒钟
     *
     * @param date Date 日期
     * @return 返回秒钟
     */
    public static int getSecond(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        return calendar.get(Calendar.SECOND);
    }

    /**
     * 功能描述：返回毫秒
     *
     * @param date 日期
     * @return 返回毫
     */
    public static long getMillis(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        return calendar.getTimeInMillis();
    }

    /**
     * 功能描述：返回当天0点到当前时间的秒数
     *
     * @param date 日期
     * @return 返回毫
     */
    public static int getDayOfSecond(Date date) {
        if (date == null) {
            return 0;
        }
        int hour = getHour(date);
        int minute = getMinute(date);
        int second = getSecond(date);

        return hour * 60 * 60 + minute * 60 + second;
    }

    /**
     * 获取一个具体时间 yyy-MM-dd hh:mm:ss时间
     *
     * @param date 日期
     * @param xxx  为是时间格式 hh:mm:ss
     * @return yyy-MM-dd hh:mm:ss
     */
    public static Date getToDayTime(Date date, String xxx) {
        String dateToHhMmStr = dateToHhMmStr(date);
        String s = dateToHhMmStr + xxx;
        return strToTime(s);
    }

    /**
     * 拼一天的开始时间
     *
     * @param date 日期
     * @return yyy-MM-dd 00:00:00
     */
    public static Date getToDayTimeStartOfDay(Date date) {
        return getToDayTime(date, START_OF_DAY);
    }

    /**
     * 拼一天的结束时间
     *
     * @param date
     * @return yyy-MM-dd 23:59:59
     */
    public static Date getToDayTimeEndOfDay(Date date) {
        return getToDayTime(date, END_OF_DAY);
    }

    /**
     * 获取今天的起始时间
     *
     * @return yyy-MM-dd hh:mm:ss
     */
    public static Date getTodayStart() {
        return getToDayTimeStartOfDay(new Date());
    }

    /**
     * 获取今天的结束时间
     *
     * @return yyy-MM-dd hh:mm:ss
     */
    public static Date getTodayEnd() {
        return getToDayTimeEndOfDay(new Date());
    }

    /**
     * @param
     * @param
     * @return
     * @throws ParseException
     */
    public static Date getDateByTimeInMillis(Long TimeInMillis) {
        Calendar c = Calendar.getInstance();
        c.setTimeInMillis(TimeInMillis);
        Date result = c.getTime();
        return result;
    }

    /**
     * 时间戳转时间
     *
     * @param i
     * @return
     */
    public static Date timeToDate(Long i) {
        if (i == null) {
            return null;
        }

        Date date = null;
        if (i > 0) {
            Long dateTime = Long.valueOf(i * 1000);
            date = new Date(dateTime);
        }
        return date;
    }

    /**
     * 出生日期字符串转化成Date对象
     *
     * @param strDate
     * @return
     * @throws ParseException
     */
    public static Date parse(String strDate) throws ParseException {
        SimpleDateFormat sdf = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd);
        return sdf.parse(strDate);
    }

    /**
     * 由出生日期获得年龄
     *
     * @param birthDay
     * @return
     * @throws Exception
     */
    public static int getAge(Date birthDay) throws Exception {
        Calendar cal = Calendar.getInstance();

        if (cal.before(birthDay)) {
            throw new IllegalArgumentException("The birthDay is before Now.It's unbelievable!");
        }
        int yearNow = cal.get(Calendar.YEAR);
        int monthNow = cal.get(Calendar.MONTH);
        int dayOfMonthNow = cal.get(Calendar.DAY_OF_MONTH);

        cal.setTime(birthDay);
        int yearBirth = cal.get(Calendar.YEAR);
        int monthBirth = cal.get(Calendar.MONTH);
        int dayOfMonthBirth = cal.get(Calendar.DAY_OF_MONTH);

        int age = yearNow - yearBirth;

        if (monthNow <= monthBirth) {
            if (monthNow == monthBirth) {
                if (dayOfMonthNow < dayOfMonthBirth) {
                    age--;
                }
            } else {
                age--;
            }
        }
        return age;
    }

    /**
     * 校验时间字符串格式
     *
     * @param dateStr
     * @return
     */
    public static boolean validDateFormat(String dateStr) {
        SimpleDateFormat sdf = new SimpleDateFormat(DATE_PATTERN_yyyy_MM_dd);
        boolean flag = true;
        try {
            sdf.setLenient(false);
            sdf.parse(dateStr);
        } catch (ParseException e) {
            flag = false;
        }
        return flag;
    }

    /**
     * 获取当前月份的上个月
     *
     * @return
     */
    public static Date getlastDayOfMonth(Date date){
        Calendar cale = Calendar.getInstance();
        cale.setTime(date);
        cale.add(Calendar.MONTH, 1);
        cale.set(Calendar.DAY_OF_MONTH, 0);
        return cale.getTime();
    }


    /**
     * 获取月份的第一天
     *
     * @return
     */
    public static   Date getFirstDayOfMonth(Date date) {
        Calendar cale = Calendar.getInstance();
        cale.setTime(date);
        cale.add(Calendar.MONTH, 0);
        cale.set(Calendar.DAY_OF_MONTH, 1);
        return cale.getTime();

    }

    public static Boolean inCurrentMonth(Date date) {
        Calendar cal1 = Calendar.getInstance();
        Calendar cal2 = Calendar.getInstance();
       //set the given date in date of the instance and current date in the other
        cal1.setTime(date);
        cal2.setTime(new Date());
       //now compare the dates using methods on Calendar
        if (cal1.get(Calendar.YEAR) == cal2.get(Calendar.YEAR)) {
            if (cal1.get(Calendar.MONTH) == cal2.get(Calendar.MONTH)) {
                return true;
            }
        }
        return false;
    }

    public static  String getNextDay(){
        Date date=new Date();//取时间
        Calendar calendar = new GregorianCalendar();
        calendar.setTime(date);
        // 1表示明天,-1表示昨天
        calendar.add(Calendar.DATE,1);
        date=calendar.getTime();
        // 这个时间就是明天
        SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
        String dateString = formatter.format(date);
        return dateString;
    }

}
